@@ -1,9 +1,9 @@
-import ConfigParser, datetime, logging, os, time, urllib, urlparse
+import ConfigParser, datetime, logging, os, time
 
 import feedparser
 
+from .download import download
 from .util import catching
-from .work_queue import work_queue
 
 logger = logging.getLogger('yoink.feed')
 
@@ -13,10 +13,12 @@ class Feed(object):
     TIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
 
     def __init__(self,
+                 name,
                  url,
                  folder,
                  timestamp,
                  config):
+        self.name = name
         self.url = url
         self.folder = folder
         self.timestamp = timestamp
@@ -51,13 +53,16 @@ class Feed(object):
         # feed's
         for enc in entry['enclosures']:
             if enc['type'].startswith('audio/'):
-                work_queue.add_job(
-                    lambda : self.download(enc['href']))
+                url = enc['href']
 
-                # Update the feed's timestamp with that of the
-                # enclosure if the enclosure's is later than the
-                # feed's
-                if not self.config.preview:
+                if self.config.preview:
+                    logger.info('[PREVIEW] Downloading {0}'.format(url))
+
+                else:
+                    # Schedule the URL for download
+                    download(url, self.folder)
+
+                    # Update the feed's timestamp
                     self.timestamp = max(
                         self.timestamp, 
                         datetime.datetime.strptime(
@@ -65,27 +70,3 @@ class Feed(object):
                                 Feed.TIME_FORMAT, 
                                 entry['updated_parsed']),
                             Feed.TIME_FORMAT))
-
-    def download(self, url):
-        '''Download a single url.
-        '''
-        if self.config.preview:
-            logger.info('[PREVIEW] Downloading {0}'.format(url))
-            return
-
-        try:
-            os.makedirs(self.folder)
-        except OSError:
-            pass
-
-        filename = os.path.split(
-            urlparse.urlparse(url).path)[1]
-
-        dest = os.path.join(self.folder, filename)
-
-        logger.info('Downloading {0} to {1}'.format(url, dest))
-        try:
-            urllib.urlretrieve(url, dest)
-
-        except Exception as e:
-            logger.error('Error downloading entry {0}: {1}'.format(url, e))
